@@ -1,15 +1,18 @@
 from django.conf.urls import patterns, url
+from django.conf import settings
 import feeds
 import views
 
 
-urlpatterns = patterns('',
-    # RSS feed
-    url(r'^feed/',
+# RSS feed
+feed_patterns = patterns('',
+    url(r'^feed/$',
         feeds.BasicPodcastFeed(),
         name='feed'),
+)
 
-    # Pages
+# Pages
+page_patterns = patterns('',
     url(r'^$',
         views.PodcastFileListView.as_view(),
         name='file-list'),
@@ -17,3 +20,10 @@ urlpatterns = patterns('',
         views.PodcastFileDetailView.as_view(),
         name='file-detail'),
 )
+
+# Build the final URL patterns, setting PODCAST_PAGES to False in settings.py
+# will disable pages.
+urlpatterns = feed_patterns
+
+if getattr(settings, 'PODCAST_PAGES', True):
+    urlpatterns += page_patterns
